@@ -12,10 +12,11 @@ from .core.universe import *
 from .core.benchmark import *
 from .core.factor import *
 from .core.portfolio import *
-from .core import aggregators as agg
 from .core import factor_model as fm
 
 from .analytics import dashboards as dash
 from .analytics import metrics
 from .analytics import tests
 from .analytics import regressions
+
+from . import utils
