@@ -22,6 +22,7 @@ __all__ = [
     "LookBackMax",
     "Lag",
     "Hold",
+    "ReplaceWithNan",
 ]
 
 Preprocessor = Callable[[pd.DataFrame], pd.DataFrame]
@@ -175,3 +176,11 @@ class Hold:
             index=values.index.copy(),
             columns=values.columns.copy()
         )
+
+
+class ReplaceWithNan:
+    def __init__(self, to_replace):
+        self.to_replace = to_replace
+
+    def __call__(self, values: pd.DataFrame) -> pd.DataFrame:
+        return values.replace(self.to_replace, np.nan)
